@@ -19,3 +19,11 @@ bash assisted-service.sh
 {% if not acm_hypershift %}
 oc -n open-cluster-management patch multiclusterhub multiclusterhub --type=merge -p '{"spec":{"overrides":{"components":[{"name":"hypershift","enabled": false}]}}}'
 {% endif %}
+
+{% if acm_siteconfig %}
+oc -n open-cluster-management patch multiclusterhub multiclusterhub --type=merge -p '{"spec":{"overrides":{"components":[{"name":"siteconfig","enabled": true}]}}}'
+{% endif %}
+
+{% if acm_ibi %}
+oc patch mce multiclusterengine --type=merge -p '{"spec":{"overrides":{"components":[{"name":"image-based-install-operator","enabled": true}]}}}'
+{% endif %}
